/**
 * DESCRIPTION: TEST_COLENDING_LOAN_AGREEMENT_DOCS DATA MODEL
 *              USED TO SAVE THE DIBURSED LOAN AGREEMENT DOC DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 02/06/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IColendingLoanAgreementDocs {
  loan_id: number;
  document_name: string;
  document_link: string;
}

// Class that implements the colending application docs interface attributes
export class ColendingLoanAgreementDocs
  extends Model<IColendingLoanAgreementDocs>
  implements IColendingLoanAgreementDocs
{
  public loan_id!: number;
  public document_name!: string;
  public document_link!: string;
}

// Define colender_loan_parameters ORM data model object
ColendingLoanAgreementDocs.init(
  {
    loan_id: {
      type: DataTypes.INTEGER,
    },
    document_name: {
      type: DataTypes.STRING(150),
    },
    document_link: {
      type: DataTypes.STRING(999),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "test_colending_loan_agreement_docs",
    sequelize,
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
ColendingLoanAgreementDocs.removeAttribute("id"); // Primary Key Attribute
ColendingLoanAgreementDocs.removeAttribute("createdAt"); // Created Date Attribute
ColendingLoanAgreementDocs.removeAttribute("updatedAt"); // Update Date Attribute
