/**
 * DESCRIPTION: TEST_COLENDER_LOAN_PARAMETER DATA MODEL
 *              USED TO SAVE THE DIBURSED LOAN DETAILS
 *              FOR THE COLENDERS
 * CREATED BY: VIKAS
 * CREATED DATE: 02/06/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IColendingMasterDetails {
  loan_id: number;
  account_number: string;
  application_id: string;
  prinicipal_amount: number;
  interest_amount: number;
  disbursement_date: number;
  first_repayment_date: Date;
  instrument_number: string;
  instrument_type: string;
  net_disbursement_amount: string;
  installment_no: string;
  installment_amount: string;
  next_repayment_date: Date;
  co_lender: string;
}

// Class that implements the pin code api interface attributes
export class ColendingMasterDetails
  extends Model<IColendingMasterDetails>
  implements IColendingMasterDetails
{
  public loan_id!: number;
  public account_number!: string;
  public application_id!: string;
  public prinicipal_amount!: number;
  public interest_amount!: number;
  public disbursement_date!: number;
  public first_repayment_date!: Date;
  public instrument_number!: string;
  public instrument_type!: string;
  public net_disbursement_amount!: string;
  public installment_no!: string;
  public installment_amount!: string;
  public next_repayment_date!: Date;
  public co_lender!: string;
}

// Define colender_loan_parameters ORM data model object
ColendingMasterDetails.init(
  {
    loan_id: {
      type: DataTypes.INTEGER,
    },
    account_number: {
      type: DataTypes.STRING(50),
    },
    application_id: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    prinicipal_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    interest_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    disbursement_date: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    first_repayment_date: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    instrument_number: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    instrument_type: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    net_disbursement_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    installment_no: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    installment_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    next_repayment_date: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    co_lender: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "test_colending_master_details",
    sequelize,
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
ColendingMasterDetails.removeAttribute("id"); // Primary Key Attribute
ColendingMasterDetails.removeAttribute("createdAt"); // Created Date Attribute
ColendingMasterDetails.removeAttribute("updatedAt"); // Update Date Attribute
