/**
 * DESCRIPTION: TEST_COLENDING_REPAYMENT_SCHEDULE DATA MODEL USED
 *              TO FETCH THE CUSTOMER DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 28/04/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IColendingRepaymentSchedule {
  loan_id: number;
  installment_due_date: Date;
  installment_amount: Date;
  installment_no: number;
  principal_amount: number;
  interest_amount: number;
  principal_outstanding: number;
}

// Class that implements the colending repayment schedule interface attributes
export class ColendingRepaymentSchedule
  extends Model<IColendingRepaymentSchedule>
  implements IColendingRepaymentSchedule
{
  public loan_id!: number;
  public installment_due_date!: Date;
  public installment_amount!: Date;
  public installment_no!: number;
  public principal_amount!: number;
  public interest_amount!: number;
  public principal_outstanding!: number;
}

// Define customer_api ORM data model object
ColendingRepaymentSchedule.init(
  {
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    installment_due_date: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    installment_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    installment_no: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    principal_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    interest_amount: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
    principal_outstanding: {
      type: DataTypes.DOUBLE(22, 0),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "test_colending_repayment_schedule",
    sequelize,
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
ColendingRepaymentSchedule.removeAttribute("id"); // Primary Key Attribute
ColendingRepaymentSchedule.removeAttribute("createdAt"); // Created Date Attribute
ColendingRepaymentSchedule.removeAttribute("updatedAt"); // Update Date Attribute
